==> massxpert2_8.5.0.orig.tar.gz: massxpert2-8.5.0/src/gui/CalculatorRecorderDlg.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#ifndef CALCULATOR_RECORDER_DLG_HPP
#define CALCULATOR_RECORDER_DLG_HPP


/////////////////////// Qt includes


/////////////////////// Local includes
#include "ui_CalculatorRecorderDlg.h"


namespace MsXpS
{

	namespace massxpert
	{



class CalculatorRecorderDlg : public QDialog
{
  Q_OBJECT

  private:
  Ui::CalculatorRecorderDlg m_ui;

  public:
  CalculatorRecorderDlg(QWidget *parent, const QString &configSettingsFilePath);

  ~CalculatorRecorderDlg();

  QString m_configSettingsFilePath;

  void record(const QString &);

  public slots:
  void close();
};

} // namespace massxpert

} // namespace MsXpS


#endif // CALCULATOR_RECORDER_DLG_HPP

==> massxpert3_10.4.0.orig.tar.gz: massxpert3-10.4.0/src/gui/CalculatorRecorderDlg.hpp <==
/* BEGIN software license
 *
 * MsXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2026 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the MsXpertSuite project.
 *
 * The MsXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
 * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#pragma once

/////////////////////// stdlib includes


/////////////////////// Qt includes


/////////////////////// pappsomspp includes


/////////////////////// libXpertMass includes


/////////////////////// libXpertMassGui includes


/////////////////////// Local includes

#include "ui_CalculatorRecorderDlg.h"


namespace MsXpS
{

namespace MassXpert
{


class CalculatorRecorderDlg : public QDialog
{
  Q_OBJECT

  private:
  Ui::CalculatorRecorderDlg m_ui;

  public:
  CalculatorRecorderDlg(QWidget *parent, const QString &configSettingsFilePath);

  ~CalculatorRecorderDlg();

  QString m_configSettingsFilePath;

  void record(const QString &);

  public slots:
  void close();
};


} // namespace MassXpert
} // namespace MsXpS
